// ignore_for_file: avoid_print

import 'dart:io';

import 'package:args/args.dart';
import 'package:path/path.dart' as path;

void main(List<String> args) async {
  final options = _generateOption(args);
  _runSetup(options);
}

GenerateOptions _generateOption(List<String> args) {
  var generateOptions = GenerateOptions();
  var parser = _generateArgParser(generateOptions);
  parser.parse(args);
  return generateOptions;
}

ArgParser _generateArgParser(GenerateOptions? generateOptions) {
  var parser = ArgParser();

  parser.addOption(
    'key',
    abbr: 'k',
    mandatory: true,
    callback: (String? x) => generateOptions!.clientKey = x,
    help: 'The Translaty client key. You can get it from your project page.',
  );

  return parser;
}

class GenerateOptions {
  String? clientKey;

  @override
  String toString() {
    return 'clientKey: $clientKey';
  }
}

void _runSetup(GenerateOptions options) async {
  final current = Directory.current;
  final translatyYaml = File(path.join(current.path, "translaty.yaml"));
  if (await translatyYaml.exists()) {
    printInfo(
      "translaty.yaml already exists. Delete it if you want to re-create it.",
    );
    return;
  }
  await translatyYaml.create();
  final content = """
translaty:
  client_key: ${options.clientKey}
""";
  await translatyYaml.writeAsString(content);
  printInfo("Successfully created translaty.yaml");
}

void printInfo(String info) {
  print('\u001b[32mTranslaty: $info\u001b[0m');
}

void printError(String error) {
  print('\u001b[31m[ERROR] Translaty: $error\u001b[0m');
}
